package com.zcloud.service.api.impl;

import com.zcloud.entity.PageData;
import com.zcloud.mapper.dsno2.api.PreventionApiMapper;
import com.zcloud.service.api.PreventionApiService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @author fangjiakai
 * @date 2023/07/28 16:03
 */
@Service
@Transactional //开启事物
public class PreventionApiServiceImpl implements PreventionApiService{
    @Autowired
    private PreventionApiMapper preventionApiMapper;

    @Override
    public PageData getDiagnosis(PageData pd) {
        return preventionApiMapper.getDiagnosis(pd);
    }

    @Override
    public List<PageData> listAllListsForDiagnosis(PageData pd) {
        return preventionApiMapper.listAllListsForDiagnosis(pd);
    }

    @Override
    public List<PageData> listDaterangeListmanager(PageData pd) {
        return preventionApiMapper.listDaterangeListmanager(pd);
    }

    @Override
    public List<PageData> listHiddenForDiagnosis(PageData pd) {
        return preventionApiMapper.listHiddenForDiagnosis(pd);
    }

    @Override
    public List<PageData> countListByUser(PageData pd) {
        return preventionApiMapper.countListByUser(pd);
    }

    @Override
    public List<PageData> countStaByUser(PageData pd) {
        return preventionApiMapper.countStaByUser(pd);
    }

    @Override
    public List<PageData> countCheByUser(PageData pd) {
        return preventionApiMapper.countCheByUser(pd);
    }

    @Override
    public List<PageData> getHiddenNum(PageData pd) {
        return preventionApiMapper.getHiddenNum(pd);
    }

    @Override
    public List<PageData> examineDeptList(PageData pd) {
        return preventionApiMapper.examineDeptList(pd);
    }

    @Override
    public List<PageData> examineUserList(PageData pd) {
        return preventionApiMapper.examineUserList(pd);
    }

    @Override
    public PageData goCorpInfoBasicInfo(PageData pd) {
        return preventionApiMapper.goCorpInfoBasicInfo(pd);
    }

    @Override
    public List<PageData> listAllRiskImg(PageData pd) {
        return preventionApiMapper.listAllRiskImg(pd);
    }

    @Override
    public List<PageData> getDeptExamine(PageData pd) {
        return preventionApiMapper.getDeptExamine(pd);
    }
}
